link_utils library
Classes
- LinkPreviewData
- Data fetched from the link
- LinkPreviewer
- LinkPreview handles
- LinkPreviewMain
- This class is only to be modified by package maintainers/contributors.
- LinkPreviewTile
- The widget displays the link preview image to the left and the title and descriptio/content to the right This class is only to be modified by package maintainers/contributors.
Enums
- DataFetchingState
- This class is only to be modified by package maintainers/contributors.